@@ -1,7 +1,7 @@
 //
 // sprites (16384 uncompressed bytes)
 //
-extern const unsigned char sprites_Bitmap[16384] = {
+const unsigned char sprites_Bitmap[16384] = {
 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x09, 0x00, 0x00, 0x00, 
 0x00, 0x00, 0x00, 0x06, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x02, 0x09, 0x00, 0x00, 
 0x00, 0x00, 0x00, 0x02, 0x02, 0x02, 0x09, 0x00, 0x00, 0x00, 0x00, 0x05, 0x02, 0x02, 0x02, 0x09, 
